# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.datacatalog_v1beta1.proto import (
    timestamps_pb2 as google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2,
)
from google.iam.v1 import iam_policy_pb2 as google_dot_iam_dot_v1_dot_iam__policy__pb2
from google.iam.v1 import policy_pb2 as google_dot_iam_dot_v1_dot_policy__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto",
    package="google.cloud.datacatalog.v1beta1",
    syntax="proto3",
    serialized_options=b"\n$com.google.cloud.datacatalog.v1beta1B\025PolicyTagManagerProtoP\001ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\370\001\001\252\002 Google.Cloud.DataCatalog.V1Beta1\312\002 Google\\Cloud\\DataCatalog\\V1beta1\352\002#Google::Cloud::DataCatalog::V1beta1",
    serialized_pb=b'\n=google/cloud/datacatalog_v1beta1/proto/policytagmanager.proto\x12 google.cloud.datacatalog.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a\x37google/cloud/datacatalog_v1beta1/proto/timestamps.proto\x1a\x1egoogle/iam/v1/iam_policy.proto\x1a\x1agoogle/iam/v1/policy.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto"\xe3\x02\n\x08Taxonomy\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x18\n\x0b\x64\x65scription\x18\x03 \x01(\tB\x03\xe0\x41\x01\x12Z\n\x16\x61\x63tivated_policy_types\x18\x06 \x03(\x0e\x32\x35.google.cloud.datacatalog.v1beta1.Taxonomy.PolicyTypeB\x03\xe0\x41\x01"J\n\nPolicyType\x12\x1b\n\x17POLICY_TYPE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x46INE_GRAINED_ACCESS_CONTROL\x10\x01:g\xea\x41\x64\n#datacatalog.googleapis.com/Taxonomy\x12=projects/{project}/locations/{location}/taxonomies/{taxonomy}"\x8c\x02\n\tPolicyTag\x12\x11\n\x04name\x18\x01 \x01(\tB\x03\xe0\x41\x03\x12\x19\n\x0c\x64isplay_name\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11parent_policy_tag\x18\x04 \x01(\t\x12\x1e\n\x11\x63hild_policy_tags\x18\x05 \x03(\tB\x03\xe0\x41\x03:\x80\x01\xea\x41}\n$datacatalog.googleapis.com/PolicyTag\x12Uprojects/{project}/locations/{location}/taxonomies/{taxonomy}/policyTags/{policy_tag}"\x92\x01\n\x15\x43reateTaxonomyRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\x12#datacatalog.googleapis.com/Taxonomy\x12<\n\x08taxonomy\x18\x02 \x01(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy"R\n\x15\x44\x65leteTaxonomyRequest\x12\x39\n\x04name\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#datacatalog.googleapis.com/Taxonomy"\x86\x01\n\x15UpdateTaxonomyRequest\x12<\n\x08taxonomy\x18\x01 \x01(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"{\n\x15ListTaxonomiesRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\x12#datacatalog.googleapis.com/Taxonomy\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"q\n\x16ListTaxonomiesResponse\x12>\n\ntaxonomies\x18\x01 \x03(\x0b\x32*.google.cloud.datacatalog.v1beta1.Taxonomy\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"O\n\x12GetTaxonomyRequest\x12\x39\n\x04name\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#datacatalog.googleapis.com/Taxonomy"\x97\x01\n\x16\x43reatePolicyTagRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$datacatalog.googleapis.com/PolicyTag\x12?\n\npolicy_tag\x18\x02 \x01(\x0b\x32+.google.cloud.datacatalog.v1beta1.PolicyTag"T\n\x16\x44\x65letePolicyTagRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$datacatalog.googleapis.com/PolicyTag"\x8a\x01\n\x16UpdatePolicyTagRequest\x12?\n\npolicy_tag\x18\x01 \x01(\x0b\x32+.google.cloud.datacatalog.v1beta1.PolicyTag\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"|\n\x15ListPolicyTagsRequest\x12<\n\x06parent\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\x12$datacatalog.googleapis.com/PolicyTag\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t"s\n\x16ListPolicyTagsResponse\x12@\n\x0bpolicy_tags\x18\x01 \x03(\x0b\x32+.google.cloud.datacatalog.v1beta1.PolicyTag\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"Q\n\x13GetPolicyTagRequest\x12:\n\x04name\x18\x01 \x01(\tB,\xe0\x41\x02\xfa\x41&\n$datacatalog.googleapis.com/PolicyTag2\xe5\x16\n\x10PolicyTagManager\x12\xce\x01\n\x0e\x43reateTaxonomy\x12\x37.google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest\x1a*.google.cloud.datacatalog.v1beta1.Taxonomy"W\x82\xd3\xe4\x93\x02?"3/v1beta1/{parent=projects/*/locations/*}/taxonomies:\x08taxonomy\xda\x41\x0fparent,taxonomy\x12\xa5\x01\n\x0e\x44\x65leteTaxonomy\x12\x37.google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest\x1a\x16.google.protobuf.Empty"B\x82\xd3\xe4\x93\x02\x35*3/v1beta1/{name=projects/*/locations/*/taxonomies/*}\xda\x41\x04name\x12\xd0\x01\n\x0eUpdateTaxonomy\x12\x37.google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest\x1a*.google.cloud.datacatalog.v1beta1.Taxonomy"Y\x82\xd3\xe4\x93\x02H2</v1beta1/{taxonomy.name=projects/*/locations/*/taxonomies/*}:\x08taxonomy\xda\x41\x08taxonomy\x12\xc9\x01\n\x0eListTaxonomies\x12\x37.google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest\x1a\x38.google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse"D\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta1/{parent=projects/*/locations/*}/taxonomies\xda\x41\x06parent\x12\xb3\x01\n\x0bGetTaxonomy\x12\x34.google.cloud.datacatalog.v1beta1.GetTaxonomyRequest\x1a*.google.cloud.datacatalog.v1beta1.Taxonomy"B\x82\xd3\xe4\x93\x02\x35\x12\x33/v1beta1/{name=projects/*/locations/*/taxonomies/*}\xda\x41\x04name\x12\xe2\x01\n\x0f\x43reatePolicyTag\x12\x38.google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest\x1a+.google.cloud.datacatalog.v1beta1.PolicyTag"h\x82\xd3\xe4\x93\x02N"@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags:\npolicy_tag\xda\x41\x11parent,policy_tag\x12\xb4\x01\n\x0f\x44\x65letePolicyTag\x12\x38.google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest\x1a\x16.google.protobuf.Empty"O\x82\xd3\xe4\x93\x02\x42*@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\xda\x41\x04name\x12\xe6\x01\n\x0fUpdatePolicyTag\x12\x38.google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest\x1a+.google.cloud.datacatalog.v1beta1.PolicyTag"l\x82\xd3\xe4\x93\x02Y2K/v1beta1/{policy_tag.name=projects/*/locations/*/taxonomies/*/policyTags/*}:\npolicy_tag\xda\x41\npolicy_tag\x12\xd6\x01\n\x0eListPolicyTags\x12\x37.google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest\x1a\x38.google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse"Q\x82\xd3\xe4\x93\x02\x42\x12@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags\xda\x41\x06parent\x12\xc3\x01\n\x0cGetPolicyTag\x12\x35.google.cloud.datacatalog.v1beta1.GetPolicyTagRequest\x1a+.google.cloud.datacatalog.v1beta1.PolicyTag"O\x82\xd3\xe4\x93\x02\x42\x12@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\xda\x41\x04name\x12\xf4\x01\n\x0cGetIamPolicy\x12".google.iam.v1.GetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"\xa8\x01\x82\xd3\xe4\x93\x02\xa1\x01"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:getIamPolicy:\x01*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:getIamPolicy:\x01*\x12\xf4\x01\n\x0cSetIamPolicy\x12".google.iam.v1.SetIamPolicyRequest\x1a\x15.google.iam.v1.Policy"\xa8\x01\x82\xd3\xe4\x93\x02\xa1\x01"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:setIamPolicy:\x01*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:setIamPolicy:\x01*\x12\xa0\x02\n\x12TestIamPermissions\x12(.google.iam.v1.TestIamPermissionsRequest\x1a).google.iam.v1.TestIamPermissionsResponse"\xb4\x01\x82\xd3\xe4\x93\x02\xad\x01"J/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:testIamPermissions:\x01*Z\\"W/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:testIamPermissions:\x01*\x1aN\xca\x41\x1a\x64\x61tacatalog.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xfb\x01\n$com.google.cloud.datacatalog.v1beta1B\x15PolicyTagManagerProtoP\x01ZKgoogle.golang.org/genproto/googleapis/cloud/datacatalog/v1beta1;datacatalog\xf8\x01\x01\xaa\x02 Google.Cloud.DataCatalog.V1Beta1\xca\x02 Google\\Cloud\\DataCatalog\\V1beta1\xea\x02#Google::Cloud::DataCatalog::V1beta1b\x06proto3',
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_datacatalog__v1beta1_dot_proto_dot_timestamps__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_iam__policy__pb2.DESCRIPTOR,
        google_dot_iam_dot_v1_dot_policy__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_TAXONOMY_POLICYTYPE = _descriptor.EnumDescriptor(
    name="PolicyType",
    full_name="google.cloud.datacatalog.v1beta1.Taxonomy.PolicyType",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="POLICY_TYPE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FINE_GRAINED_ACCESS_CONTROL",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=571,
    serialized_end=645,
)
_sym_db.RegisterEnumDescriptor(_TAXONOMY_POLICYTYPE)


_TAXONOMY = _descriptor.Descriptor(
    name="Taxonomy",
    full_name="google.cloud.datacatalog.v1beta1.Taxonomy",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="activated_policy_types",
            full_name="google.cloud.datacatalog.v1beta1.Taxonomy.activated_policy_types",
            index=3,
            number=6,
            type=14,
            cpp_type=8,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\001",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_TAXONOMY_POLICYTYPE],
    serialized_options=b"\352Ad\n#datacatalog.googleapis.com/Taxonomy\022=projects/{project}/locations/{location}/taxonomies/{taxonomy}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=395,
    serialized_end=750,
)


_POLICYTAG = _descriptor.Descriptor(
    name="PolicyTag",
    full_name="google.cloud.datacatalog.v1beta1.PolicyTag",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="display_name",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.display_name",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="description",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.description",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="parent_policy_tag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.parent_policy_tag",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="child_policy_tags",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTag.child_policy_tags",
            index=4,
            number=5,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\003",
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=b"\352A}\n$datacatalog.googleapis.com/PolicyTag\022Uprojects/{project}/locations/{location}/taxonomies/{taxonomy}/policyTags/{policy_tag}",
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=753,
    serialized_end=1021,
)


_CREATETAXONOMYREQUEST = _descriptor.Descriptor(
    name="CreateTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\022#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="taxonomy",
            full_name="google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest.taxonomy",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1024,
    serialized_end=1170,
)


_DELETETAXONOMYREQUEST = _descriptor.Descriptor(
    name="DeleteTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\n#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1172,
    serialized_end=1254,
)


_UPDATETAXONOMYREQUEST = _descriptor.Descriptor(
    name="UpdateTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomy",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest.taxonomy",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1257,
    serialized_end=1391,
)


_LISTTAXONOMIESREQUEST = _descriptor.Descriptor(
    name="ListTaxonomiesRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\022#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1393,
    serialized_end=1516,
)


_LISTTAXONOMIESRESPONSE = _descriptor.Descriptor(
    name="ListTaxonomiesResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="taxonomies",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse.taxonomies",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1518,
    serialized_end=1631,
)


_GETTAXONOMYREQUEST = _descriptor.Descriptor(
    name="GetTaxonomyRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetTaxonomyRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetTaxonomyRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A%\n#datacatalog.googleapis.com/Taxonomy",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1633,
    serialized_end=1712,
)


_CREATEPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="CreatePolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="policy_tag",
            full_name="google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest.policy_tag",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1715,
    serialized_end=1866,
)


_DELETEPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="DeletePolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1868,
    serialized_end=1952,
)


_UPDATEPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="UpdatePolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="policy_tag",
            full_name="google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest.policy_tag",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1955,
    serialized_end=2093,
)


_LISTPOLICYTAGSREQUEST = _descriptor.Descriptor(
    name="ListPolicyTagsRequest",
    full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\022$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest.page_size",
            index=1,
            number=2,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2095,
    serialized_end=2219,
)


_LISTPOLICYTAGSRESPONSE = _descriptor.Descriptor(
    name="ListPolicyTagsResponse",
    full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="policy_tags",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse.policy_tags",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2221,
    serialized_end=2336,
)


_GETPOLICYTAGREQUEST = _descriptor.Descriptor(
    name="GetPolicyTagRequest",
    full_name="google.cloud.datacatalog.v1beta1.GetPolicyTagRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.datacatalog.v1beta1.GetPolicyTagRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=b"".decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=b"\340A\002\372A&\n$datacatalog.googleapis.com/PolicyTag",
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2338,
    serialized_end=2419,
)

_TAXONOMY.fields_by_name["activated_policy_types"].enum_type = _TAXONOMY_POLICYTYPE
_TAXONOMY_POLICYTYPE.containing_type = _TAXONOMY
_CREATETAXONOMYREQUEST.fields_by_name["taxonomy"].message_type = _TAXONOMY
_UPDATETAXONOMYREQUEST.fields_by_name["taxonomy"].message_type = _TAXONOMY
_UPDATETAXONOMYREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTTAXONOMIESRESPONSE.fields_by_name["taxonomies"].message_type = _TAXONOMY
_CREATEPOLICYTAGREQUEST.fields_by_name["policy_tag"].message_type = _POLICYTAG
_UPDATEPOLICYTAGREQUEST.fields_by_name["policy_tag"].message_type = _POLICYTAG
_UPDATEPOLICYTAGREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTPOLICYTAGSRESPONSE.fields_by_name["policy_tags"].message_type = _POLICYTAG
DESCRIPTOR.message_types_by_name["Taxonomy"] = _TAXONOMY
DESCRIPTOR.message_types_by_name["PolicyTag"] = _POLICYTAG
DESCRIPTOR.message_types_by_name["CreateTaxonomyRequest"] = _CREATETAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["DeleteTaxonomyRequest"] = _DELETETAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["UpdateTaxonomyRequest"] = _UPDATETAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["ListTaxonomiesRequest"] = _LISTTAXONOMIESREQUEST
DESCRIPTOR.message_types_by_name["ListTaxonomiesResponse"] = _LISTTAXONOMIESRESPONSE
DESCRIPTOR.message_types_by_name["GetTaxonomyRequest"] = _GETTAXONOMYREQUEST
DESCRIPTOR.message_types_by_name["CreatePolicyTagRequest"] = _CREATEPOLICYTAGREQUEST
DESCRIPTOR.message_types_by_name["DeletePolicyTagRequest"] = _DELETEPOLICYTAGREQUEST
DESCRIPTOR.message_types_by_name["UpdatePolicyTagRequest"] = _UPDATEPOLICYTAGREQUEST
DESCRIPTOR.message_types_by_name["ListPolicyTagsRequest"] = _LISTPOLICYTAGSREQUEST
DESCRIPTOR.message_types_by_name["ListPolicyTagsResponse"] = _LISTPOLICYTAGSRESPONSE
DESCRIPTOR.message_types_by_name["GetPolicyTagRequest"] = _GETPOLICYTAGREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Taxonomy = _reflection.GeneratedProtocolMessageType(
    "Taxonomy",
    (_message.Message,),
    {
        "DESCRIPTOR": _TAXONOMY,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """A taxonomy is a collection of policy tags that classify
  data along a common axis. For instance a data *sensitivity* taxonomy
  could contain policy tags denoting PII such as age, zipcode, and SSN. A
  data *origin* taxonomy could contain policy tags to distinguish user
  data, employee data, partner data, public data.
  
  
  Attributes:
      name:
          Output only. Resource name of this taxonomy, whose format is: 
          “projects/{project_number}/locations/{location_id}/taxonomies/
          {id}”.
      display_name:
          Required. User defined name of this taxonomy. It must: contain
          only unicode letters, numbers, underscores, dashes and spaces;
          not start or end with spaces; and be at most 200 bytes long
          when encoded in UTF-8.
      description:
          Optional. Description of this taxonomy. It must: contain only
          unicode characters, tabs, newlines, carriage returns and page
          breaks; and be at most 2000 bytes long when encoded in UTF-8.
          If not set, defaults to an empty description.
      activated_policy_types:
          Optional. A list of policy types that are activated for this
          taxonomy. If not set, defaults to an empty list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.Taxonomy)
    },
)
_sym_db.RegisterMessage(Taxonomy)

PolicyTag = _reflection.GeneratedProtocolMessageType(
    "PolicyTag",
    (_message.Message,),
    {
        "DESCRIPTOR": _POLICYTAG,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Denotes one policy tag in a taxonomy (e.g. ssn). Policy
  Tags can be defined in a hierarchy. For example, consider the following
  hierarchy: Geolocation -> (LatLong, City, ZipCode). PolicyTag
  “Geolocation” contains three child policy tags: “LatLong”, “City”, and
  “ZipCode”.
  
  
  Attributes:
      name:
          Output only. Resource name of this policy tag, whose format
          is: “projects/{project_number}/locations/{location_id}/taxonom
          ies/{taxonomy_id}/policyTags/{id}”.
      display_name:
          Required. User defined name of this policy tag. It must: be
          unique within the parent taxonomy; contain only unicode
          letters, numbers, underscores, dashes and spaces; not start or
          end with spaces; and be at most 200 bytes long when encoded in
          UTF-8.
      description:
          Description of this policy tag. It must: contain only unicode
          characters, tabs, newlines, carriage returns and page breaks;
          and be at most 2000 bytes long when encoded in UTF-8. If not
          set, defaults to an empty description. If not set, defaults to
          an empty description.
      parent_policy_tag:
          Resource name of this policy tag’s parent policy tag (e.g. for
          the “LatLong” policy tag in the example above, this field
          contains the resource name of the “Geolocation” policy tag).
          If empty, it means this policy tag is a top level policy tag
          (e.g. this field is empty for the “Geolocation” policy tag in
          the example above). If not set, defaults to an empty string.
      child_policy_tags:
          Output only. Resource names of child policy tags of this
          policy tag.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.PolicyTag)
    },
)
_sym_db.RegisterMessage(PolicyTag)

CreateTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "CreateTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATETAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [CreateTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.CreateTaxonomy].
  
  
  Attributes:
      parent:
          Required. Resource name of the project that the taxonomy will
          belong to.
      taxonomy:
          The taxonomy to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreateTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(CreateTaxonomyRequest)

DeleteTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETETAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [DeleteTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.DeleteTaxonomy].
  
  
  Attributes:
      name:
          Required. Resource name of the taxonomy to be deleted. All
          policy tags in this taxonomy will also be deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeleteTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(DeleteTaxonomyRequest)

UpdateTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATETAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [UpdateTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdateTaxonomy].
  
  
  Attributes:
      taxonomy:
          The taxonomy to update. Only description, display_name, and
          activated policy types can be updated.
      update_mask:
          The update mask applies to the resource. For the ``FieldMask``
          definition, see https://developers.google.com/protocol-
          buffers/docs/reference/google.protobuf#fieldmask If not set,
          defaults to all of the fields that are allowed to update.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdateTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(UpdateTaxonomyRequest)

ListTaxonomiesRequest = _reflection.GeneratedProtocolMessageType(
    "ListTaxonomiesRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTAXONOMIESREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [ListTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListTaxonomies].
  
  
  Attributes:
      parent:
          Required. Resource name of the project to list the taxonomies
          of.
      page_size:
          The maximum number of items to return. Must be a value between
          1 and 1000. If not set, defaults to 50.
      page_token:
          The next_page_token value returned from a previous list
          request, if any. If not set, defaults to an empty string.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTaxonomiesRequest)
    },
)
_sym_db.RegisterMessage(ListTaxonomiesRequest)

ListTaxonomiesResponse = _reflection.GeneratedProtocolMessageType(
    "ListTaxonomiesResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTTAXONOMIESRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Response message for
  [ListTaxonomies][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListTaxonomies].
  
  
  Attributes:
      taxonomies:
          Taxonomies that the project contains.
      next_page_token:
          Token used to retrieve the next page of results, or empty if
          there are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListTaxonomiesResponse)
    },
)
_sym_db.RegisterMessage(ListTaxonomiesResponse)

GetTaxonomyRequest = _reflection.GeneratedProtocolMessageType(
    "GetTaxonomyRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETTAXONOMYREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [GetTaxonomy][google.cloud.datacatalog.v1beta1.PolicyTagManager.GetTaxonomy].
  
  
  Attributes:
      name:
          Required. Resource name of the requested taxonomy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetTaxonomyRequest)
    },
)
_sym_db.RegisterMessage(GetTaxonomyRequest)

CreatePolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "CreatePolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _CREATEPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [CreatePolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.CreatePolicyTag].
  
  
  Attributes:
      parent:
          Required. Resource name of the taxonomy that the policy tag
          will belong to.
      policy_tag:
          The policy tag to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.CreatePolicyTagRequest)
    },
)
_sym_db.RegisterMessage(CreatePolicyTagRequest)

DeletePolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "DeletePolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _DELETEPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [DeletePolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.DeletePolicyTag].
  
  
  Attributes:
      name:
          Required. Resource name of the policy tag to be deleted. All
          of its descendant policy tags will also be deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.DeletePolicyTagRequest)
    },
)
_sym_db.RegisterMessage(DeletePolicyTagRequest)

UpdatePolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "UpdatePolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _UPDATEPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [UpdatePolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdatePolicyTag].
  
  
  Attributes:
      policy_tag:
          The policy tag to update. Only the description, display_name,
          and parent_policy_tag fields can be updated.
      update_mask:
          The update mask applies to the resource. Only display_name,
          description and parent_policy_tag can be updated and thus can
          be listed in the mask. If update_mask is not provided, all
          allowed fields (i.e. display_name, description and parent)
          will be updated. For more information including the
          ``FieldMask`` definition, see
          https://developers.google.com/protocol-
          buffers/docs/reference/google.protobuf#fieldmask If not set,
          defaults to all of the fields that are allowed to update.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.UpdatePolicyTagRequest)
    },
)
_sym_db.RegisterMessage(UpdatePolicyTagRequest)

ListPolicyTagsRequest = _reflection.GeneratedProtocolMessageType(
    "ListPolicyTagsRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTPOLICYTAGSREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [ListPolicyTags][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListPolicyTags].
  
  
  Attributes:
      parent:
          Required. Resource name of the taxonomy to list the policy
          tags of.
      page_size:
          The maximum number of items to return. Must be a value between
          1 and 1000. If not set, defaults to 50.
      page_token:
          The next_page_token value returned from a previous List
          request, if any. If not set, defaults to an empty string.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListPolicyTagsRequest)
    },
)
_sym_db.RegisterMessage(ListPolicyTagsRequest)

ListPolicyTagsResponse = _reflection.GeneratedProtocolMessageType(
    "ListPolicyTagsResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTPOLICYTAGSRESPONSE,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Response message for
  [ListPolicyTags][google.cloud.datacatalog.v1beta1.PolicyTagManager.ListPolicyTags].
  
  
  Attributes:
      policy_tags:
          The policy tags that are in the requested taxonomy.
      next_page_token:
          Token used to retrieve the next page of results, or empty if
          there are no more results in the list.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.ListPolicyTagsResponse)
    },
)
_sym_db.RegisterMessage(ListPolicyTagsResponse)

GetPolicyTagRequest = _reflection.GeneratedProtocolMessageType(
    "GetPolicyTagRequest",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETPOLICYTAGREQUEST,
        "__module__": "google.cloud.datacatalog_v1beta1.proto.policytagmanager_pb2",
        "__doc__": """Request message for
  [GetPolicyTag][google.cloud.datacatalog.v1beta1.PolicyTagManager.GetPolicyTag].
  
  
  Attributes:
      name:
          Required. Resource name of the requested policy tag.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.datacatalog.v1beta1.GetPolicyTagRequest)
    },
)
_sym_db.RegisterMessage(GetPolicyTagRequest)


DESCRIPTOR._options = None
_TAXONOMY.fields_by_name["name"]._options = None
_TAXONOMY.fields_by_name["display_name"]._options = None
_TAXONOMY.fields_by_name["description"]._options = None
_TAXONOMY.fields_by_name["activated_policy_types"]._options = None
_TAXONOMY._options = None
_POLICYTAG.fields_by_name["name"]._options = None
_POLICYTAG.fields_by_name["display_name"]._options = None
_POLICYTAG.fields_by_name["child_policy_tags"]._options = None
_POLICYTAG._options = None
_CREATETAXONOMYREQUEST.fields_by_name["parent"]._options = None
_DELETETAXONOMYREQUEST.fields_by_name["name"]._options = None
_LISTTAXONOMIESREQUEST.fields_by_name["parent"]._options = None
_GETTAXONOMYREQUEST.fields_by_name["name"]._options = None
_CREATEPOLICYTAGREQUEST.fields_by_name["parent"]._options = None
_DELETEPOLICYTAGREQUEST.fields_by_name["name"]._options = None
_LISTPOLICYTAGSREQUEST.fields_by_name["parent"]._options = None
_GETPOLICYTAGREQUEST.fields_by_name["name"]._options = None

_POLICYTAGMANAGER = _descriptor.ServiceDescriptor(
    name="PolicyTagManager",
    full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager",
    file=DESCRIPTOR,
    index=0,
    serialized_options=b"\312A\032datacatalog.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform",
    serialized_start=2422,
    serialized_end=5339,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.CreateTaxonomy",
            index=0,
            containing_service=None,
            input_type=_CREATETAXONOMYREQUEST,
            output_type=_TAXONOMY,
            serialized_options=b'\202\323\344\223\002?"3/v1beta1/{parent=projects/*/locations/*}/taxonomies:\010taxonomy\332A\017parent,taxonomy',
        ),
        _descriptor.MethodDescriptor(
            name="DeleteTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.DeleteTaxonomy",
            index=1,
            containing_service=None,
            input_type=_DELETETAXONOMYREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\0025*3/v1beta1/{name=projects/*/locations/*/taxonomies/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="UpdateTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdateTaxonomy",
            index=2,
            containing_service=None,
            input_type=_UPDATETAXONOMYREQUEST,
            output_type=_TAXONOMY,
            serialized_options=b"\202\323\344\223\002H2</v1beta1/{taxonomy.name=projects/*/locations/*/taxonomies/*}:\010taxonomy\332A\010taxonomy",
        ),
        _descriptor.MethodDescriptor(
            name="ListTaxonomies",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.ListTaxonomies",
            index=3,
            containing_service=None,
            input_type=_LISTTAXONOMIESREQUEST,
            output_type=_LISTTAXONOMIESRESPONSE,
            serialized_options=b"\202\323\344\223\0025\0223/v1beta1/{parent=projects/*/locations/*}/taxonomies\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="GetTaxonomy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.GetTaxonomy",
            index=4,
            containing_service=None,
            input_type=_GETTAXONOMYREQUEST,
            output_type=_TAXONOMY,
            serialized_options=b"\202\323\344\223\0025\0223/v1beta1/{name=projects/*/locations/*/taxonomies/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="CreatePolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.CreatePolicyTag",
            index=5,
            containing_service=None,
            input_type=_CREATEPOLICYTAGREQUEST,
            output_type=_POLICYTAG,
            serialized_options=b'\202\323\344\223\002N"@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags:\npolicy_tag\332A\021parent,policy_tag',
        ),
        _descriptor.MethodDescriptor(
            name="DeletePolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.DeletePolicyTag",
            index=6,
            containing_service=None,
            input_type=_DELETEPOLICYTAGREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=b"\202\323\344\223\002B*@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="UpdatePolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.UpdatePolicyTag",
            index=7,
            containing_service=None,
            input_type=_UPDATEPOLICYTAGREQUEST,
            output_type=_POLICYTAG,
            serialized_options=b"\202\323\344\223\002Y2K/v1beta1/{policy_tag.name=projects/*/locations/*/taxonomies/*/policyTags/*}:\npolicy_tag\332A\npolicy_tag",
        ),
        _descriptor.MethodDescriptor(
            name="ListPolicyTags",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.ListPolicyTags",
            index=8,
            containing_service=None,
            input_type=_LISTPOLICYTAGSREQUEST,
            output_type=_LISTPOLICYTAGSRESPONSE,
            serialized_options=b"\202\323\344\223\002B\022@/v1beta1/{parent=projects/*/locations/*/taxonomies/*}/policyTags\332A\006parent",
        ),
        _descriptor.MethodDescriptor(
            name="GetPolicyTag",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.GetPolicyTag",
            index=9,
            containing_service=None,
            input_type=_GETPOLICYTAGREQUEST,
            output_type=_POLICYTAG,
            serialized_options=b"\202\323\344\223\002B\022@/v1beta1/{name=projects/*/locations/*/taxonomies/*/policyTags/*}\332A\004name",
        ),
        _descriptor.MethodDescriptor(
            name="GetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.GetIamPolicy",
            index=10,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._GETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=b'\202\323\344\223\002\241\001"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:getIamPolicy:\001*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:getIamPolicy:\001*',
        ),
        _descriptor.MethodDescriptor(
            name="SetIamPolicy",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.SetIamPolicy",
            index=11,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._SETIAMPOLICYREQUEST,
            output_type=google_dot_iam_dot_v1_dot_policy__pb2._POLICY,
            serialized_options=b'\202\323\344\223\002\241\001"D/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:setIamPolicy:\001*ZV"Q/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:setIamPolicy:\001*',
        ),
        _descriptor.MethodDescriptor(
            name="TestIamPermissions",
            full_name="google.cloud.datacatalog.v1beta1.PolicyTagManager.TestIamPermissions",
            index=12,
            containing_service=None,
            input_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSREQUEST,
            output_type=google_dot_iam_dot_v1_dot_iam__policy__pb2._TESTIAMPERMISSIONSRESPONSE,
            serialized_options=b'\202\323\344\223\002\255\001"J/v1beta1/{resource=projects/*/locations/*/taxonomies/*}:testIamPermissions:\001*Z\\"W/v1beta1/{resource=projects/*/locations/*/taxonomies/*/policyTags/*}:testIamPermissions:\001*',
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_POLICYTAGMANAGER)

DESCRIPTOR.services_by_name["PolicyTagManager"] = _POLICYTAGMANAGER

# @@protoc_insertion_point(module_scope)
